import RetailParamsRepository from '../Repositories/RetailParamsRepository.js'
import { log } from './LogController.js'

// Esta é a função que deve ser chamada quando for enviar dados para o FRONTEND
const getRetailGeneralParams = async function () {
    const retailParams = await RetailParamsRepository.getRetailGeneralParams()
    // Deleta os parâmetros que são utilizados exclusivamente pelo backend antes de enviar para o front
    delete retailParams.RECSENHAMSG
    delete retailParams.URLAPIPAG
    delete retailParams.URLAPIFINANCEIRO
    delete retailParams.EMAILOPER_FIN
    delete retailParams.SENHAOPER_FIN
    delete retailParams.MERCHANTID
    delete retailParams.MERCHANTKEY
    delete retailParams.PAYMENTCOMPANY
    return retailParams ? retailParams : {}
}

// Esta função deve ser chamada APENAS PARA USO DOS DADOS DENTRO DO BACKEND, porque expõe dados sensíveis
const getRetailGeneralParamsBackend = async function () {
    const retailParams = await RetailParamsRepository.getRetailGeneralParams()
    return retailParams ? retailParams : {}
}

const getRetailSpecificParams = async function (CDCLIENTE, CDFILIAL) {
    const retailParams = await RetailParamsRepository.getRetailSpecificParams(CDCLIENTE, CDFILIAL)

    if (retailParams) {
        try {
            retailParams.ENABLED_PAYMENTS = JSON.parse(retailParams.PAGHABJSON).ENABLED_PAYMENTS
        } catch (error) {
            retailParams.ENABLED_PAYMENTS = []
            log({ type: 'error', message: `Erro ao parsear o campo PAGHABJSON:\n${error.message}` })
        }
        delete retailParams.PAGHABJSON
    }
    
    return retailParams ? retailParams : {}
}

const getPaymentApiUrl = async function () {
    const retailParams = await RetailParamsRepository.getRetailGeneralParams()
    return retailParams?.URLAPIPAG ? retailParams.URLAPIPAG : ''
}

const getApiFinancData = async function () {
    const retailParams = await RetailParamsRepository.getRetailGeneralParams()

    return {
        URLAPIFINANCEIRO: retailParams?.URLAPIFINANCEIRO ? retailParams.URLAPIFINANCEIRO : '',
        EMAILOPER_FIN: retailParams?.EMAILOPER_FIN ? retailParams.EMAILOPER_FIN : '',
        SENHAOPER_FIN: retailParams?.SENHAOPER_FIN ? retailParams.SENHAOPER_FIN : ''
    }
}

export {
    getRetailGeneralParams,
    getRetailGeneralParamsBackend,
    getRetailSpecificParams,
    getPaymentApiUrl,
    getApiFinancData
}
